Fledex.Color.Conversion.Rainbow (fledex v0.7.0)

Module defininig an hsv2rgb/2 conversion following the rainbow color map.

This does give more enphasis to yellow. An alternative color map would be the Spectrum color map, which has very little yellow which often feels less natural.

Summary

Functions

Fledex uses by default a Rainbow color conversion from HSV to RGB

Functions

hsv2rgb(hsv, extra_color_correction)

Fledex uses by default a Rainbow color conversion from HSV to RGB

Fledex does also provide a Fledex.Color.Conversion.Spectrum color conversion, but more effort from your side is required to use them. See this great article to understand the difference between the two