Fledex.Color.Correction.Temperature (fledex v0.7.0)
View SourceColor temperature values
These color values are separated into two groups: black body radiators and gaseous light sources.
Black body radiators emit a (relatively) continuous spectrum, and can be described as having a Kelvin 'temperature'. This includes things like candles, tungsten lightbulbs, and sunlight.
Gaseous light sources emit discrete spectral bands, and while we can approximate their aggregate hue with RGB values, they don't actually have a proper Kelvin temperature.
See wikipedia:
Summary
Functions
Gaseous Light Source: Black light flourescent light bulbs, 0 K, (167, 0, 255)
Black Body Radiator: 1900K (255, 147, 41)
Black Body Radiator: 5200K (255, 250, 244)
Black Body Radiator: 20000K (64, 156, 255)
Gaseous Light Source: Cool white (bluer) flourescent light bulbs, 0 K, (212, 235, 255)
Black Body Radiator: 6000K (255, 255, 255)
Gaseous Light Source: Full spectrum flourescent light bulbs, 0 K, (255, 244, 242)
Gaseous Light Source: Grow light flourescent light bulbs, 0 K, (255, 239, 247)
Black Body Radiator: 3200K (255, 241, 224)
Black Body Radiator: 5400K (255, 255, 251)
Gaseous Light Source: High-pressure sodium light bulbs, 0 K, (255, 183, 76)
Gaseous Light Source: Mercury vapor light bulbs, 0 K, (216, 247, 255)
Gaseous Light Source: Metal-halide light bulbs: 0 K, (242, 252, 255)
Black Body Radiator: 7000K (201, 226, 255)
Gaseous Light Source: Sodium vapor light bulbs, 0 K, (255, 209, 178)
Gaseous Light Source: Standard flourescent light bulbs, 0 K, (244, 255, 250)
Black Body Radiator: 2600K (255, 197, 143)
Black Body Radiator: 2850K (255, 214, 170)
Uncorrected temperature, (255, 255, 255)
Gaseous Light Source: Warm (yellower) flourescent light bulbs, 0 K, (255, 244, 229)
Functions
@spec black_light_fluorescent() :: 10_944_767
Gaseous Light Source: Black light flourescent light bulbs, 0 K, (167, 0, 255)
@spec candle() :: 16_749_353
Black Body Radiator: 1900K (255, 147, 41)
@spec carbon_arc() :: 16_775_924
Black Body Radiator: 5200K (255, 250, 244)
@spec clear_blue_sky() :: 4_234_495
Black Body Radiator: 20000K (64, 156, 255)
@spec cool_white_fluorescent() :: 13_954_047
Gaseous Light Source: Cool white (bluer) flourescent light bulbs, 0 K, (212, 235, 255)
@spec direct_sunlight() :: 16_777_215
Black Body Radiator: 6000K (255, 255, 255)
@spec full_spectrum_fluorescent() :: 16_774_386
Gaseous Light Source: Full spectrum flourescent light bulbs, 0 K, (255, 244, 242)
@spec grow_light_fluorescent() :: 16_773_111
Gaseous Light Source: Grow light flourescent light bulbs, 0 K, (255, 239, 247)
@spec halogen() :: 16_773_600
Black Body Radiator: 3200K (255, 241, 224)
@spec high_noon_sun() :: 16_777_211
Black Body Radiator: 5400K (255, 255, 251)
@spec high_pressure_sodium() :: 16_758_604
Gaseous Light Source: High-pressure sodium light bulbs, 0 K, (255, 183, 76)
@spec mercury_vapor() :: 14_219_263
Gaseous Light Source: Mercury vapor light bulbs, 0 K, (216, 247, 255)
@spec metal_halide() :: 15_924_479
Gaseous Light Source: Metal-halide light bulbs: 0 K, (242, 252, 255)
@spec overcast_sky() :: 13_230_847
Black Body Radiator: 7000K (201, 226, 255)
@spec sodium_vapor() :: 16_765_362
Gaseous Light Source: Sodium vapor light bulbs, 0 K, (255, 209, 178)
@spec standard_fluorescent() :: 16_056_314
Gaseous Light Source: Standard flourescent light bulbs, 0 K, (244, 255, 250)
@spec tungsten_40w() :: 16_762_255
Black Body Radiator: 2600K (255, 197, 143)
@spec tungsten_100w() :: 16_766_634
Black Body Radiator: 2850K (255, 214, 170)
@spec uncorrected_temperature() :: 16_777_215
Uncorrected temperature, (255, 255, 255)
@spec warm_fluorescent() :: 16_774_373
Gaseous Light Source: Warm (yellower) flourescent light bulbs, 0 K, (255, 244, 229)