Fledex.Color.Names.Types (fledex v0.7.0)
View SourceThis module defines a couple of types related to color names
Summary
Types
any atom could be a valid color name
The different properties that can be interrogated from a named color
The structure of a named color with all it's attributes.
The different values that can be returned when interrogating for some named color properties
Types
@type color_name_t() :: atom()
any atom could be a valid color name
@type color_props_t() ::
:all
| :index
| :name
| :descriptive_name
| :hex
| :rgb
| :hsl
| :hsv
| :source
The different properties that can be interrogated from a named color
@type color_struct_t() :: %{ optional(atom()) => any(), optional(:descriptive_name) => String.t(), optional(:rgb) => Fledex.Color.Types.rgb(), optional(:hsl) => Fledex.Color.Types.hsl(), optional(:hsv) => Fledex.Color.Types.hsv(), optional(:source) => String.t(), optional(:index) => integer(), name: color_name_t(), hex: Fledex.Color.Types.colorint(), module: module() }
The structure of a named color with all it's attributes.
@type color_vals_t() :: Fledex.Color.Types.color_any() | color_struct_t() | String.t() | module()
The different values that can be returned when interrogating for some named color properties