Fledex.Driver.Impl.Logger (fledex v0.7.0)
View SourceThis driver can log the data either to IO or to a Logger.
When logging to IO an attempt is made to preserve the colors, which is difficult due to the more restrictive nature of the IO colors (5bit instead of 8bit). It's probably best to stick to the ANSI defined colors
Options
The following options can be passed to this driver:
:update_freq: the frequency on how often the data is dumped (default:10, meaning that only every10th redraw is printed out).:color: whether to use terminal colors in the output (default:false):terminal: whether to dump to the terminal (true, default) or to theLogger(false)