Fledex.Color.Correction.Color (fledex v0.7.0)
View SourceColor correction depending on the hardware used
Summary
Functions
Typical values for 8 mm "pixels on a string"
Use this if you don't know the led type, it will be configured to the most appropriate value for led strips.
same as typical_8mm_pixel
Typical values for SMD5050 LEDs (255, 176, 240)
To be used if you don't want to correct the color, i.e. all with full intensity (255, 255, 255)
Functions
@spec typical_8mm_pixel() :: 16_769_164
Typical values for 8 mm "pixels on a string"
@spec typical_led_strip() :: 16_756_976
Use this if you don't know the led type, it will be configured to the most appropriate value for led strips.
@spec typical_pixel_string() :: 16_769_164
same as typical_8mm_pixel
@spec typical_smd5050() :: 16_756_976
Typical values for SMD5050 LEDs (255, 176, 240)
@spec uncorrected_color() :: 16_777_215
To be used if you don't want to correct the color, i.e. all with full intensity (255, 255, 255)