Fledex.Driver.Impl.Spi (fledex v0.7.0)
View SourceThis module is a concrete driver that will push the led data through an SPI port.
The protocol used is the one as expected by an WS2801 chip. See the hardware documentation for more information on to wire it.
Options
This driver accepts the following options (most of them are very SPI specific and the defaults are probably good enough):
:dev: SPI device name (default "spidev0.0", seeCircuits.SPI.spi_option/0for details).:mode: set clock polarity and phase (default: mode0, seeCircuits.SPI.spi_option/0for details),:bits_per_word: set the bits per word on the bus (default:8, seeCircuits.SPI.spi_option/0for details).:speed_hz: set the bus speed (default:1_000_000, seeCircuits.SPI.spi_option/0for details).:delay_us: set the delay between transactions (default:10, seeCircuits.SPI.spi_option/0for details).:lsb_first: sets whether the least significant bit is first (default:false, seeCircuits.SPI.spi_option/0for details).:color_correction: specifies the color correction (seeFledex.Color.Correctionfor details):clear_leds: Sets the number of leds that should be cleared during startup (default:0)